BTreeMap

Struct BTreeMap 

pub struct BTreeMap<K, V, const N: usize>(/* private fields */);
An ordered map based on a B-Tree (with alloc) or a linear map (with heapless).

When heapless feature is enabled, this is a wrapper around heapless::LinearMap<K, V, N>.

Note: With heapless, iteration order is insertion order, not key order.

Implementations

Source

impl<K, V, const N: usize> BTreeMap<K, V, N>
where K: Ord + Eq,

pub fn new() -> Self

Constructs a new, empty map.

pub fn get(&self, key: &K) -> Option<&V>

Returns a reference to the value corresponding to the key.

pub fn contains_key(&self, key: &K) -> bool

Returns true if the map contains a value for the specified key.

pub fn insert(&mut self, key: K, value: V) -> Result<Option<V>>

Inserts a key-value pair into the map.

If the map did not have this key present, Ok(None) is returned. If the map did have this key present, the value is updated, and Ok(Some(old_value)) is returned. Returns Err if the map is at capacity (heapless only).

pub fn remove(&mut self, key: &K) -> Option<V>

Removes a key from the map, returning the value at the key if the key was previously in the map.

Source

impl<K, V, const N: usize> BTreeMap<K, V, N>
where K: Eq,

pub fn len(&self) -> usize

Returns the number of elements in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn clear(&mut self)

Clears the map, removing all elements.

pub fn iter(&self) -> impl Iterator<Item = (&K, &V)>

Returns an iterator over the map’s key-value pairs.

pub fn keys(&self) -> impl Iterator<Item = &K>

Returns an iterator over the map’s keys.

pub fn values(&self) -> impl Iterator<Item = &V>

Returns an iterator over the map’s values.